pub struct Label<'a> {
pub key: &'a str,
pub str: &'a str,
pub num: i64,
pub num_unit: &'a str,
}Fields
key: &'a strstr: &'a strAt most one of the following must be present
num: i64num_unit: &'a strShould only be present when num is present. Specifies the units of num. Use arbitrary string (for example, “requests”) as a custom count unit. If no unit is specified, consumer may apply heuristic to deduce the unit. Consumers may also interpret units like “bytes” and “kilobytes” as memory units and units like “seconds” and “nanoseconds” as time units, and apply appropriate unit conversions to these.
Implementations