pub struct Location<'a> {
pub mapping: Mapping<'a>,
pub function: Function<'a>,
pub address: u64,
pub line: i64,
}Fields
mapping: Mapping<'a>function: Function<'a>address: u64The instruction address for this location, if available. It should be within [Mapping.memory_start…Mapping.memory_limit] for the corresponding mapping. A non-leaf address may be in the middle of a call instruction. It is up to display tools to find the beginning of the instruction if necessary.
line: i64Trait Implementations
impl<'a> Copy for Location<'a>
impl<'a> Eq for Location<'a>
impl<'a> StructuralPartialEq for Location<'a>