pub struct Mapping<'a> {
pub memory_start: u64,
pub memory_limit: u64,
pub file_offset: u64,
pub filename: &'a str,
pub build_id: &'a str,
}Fields
memory_start: u64Address at which the binary (or DLL) is loaded into memory.
memory_limit: u64The limit of the address range occupied by this mapping.
file_offset: u64Offset in the binary that corresponds to the first mapped address.
filename: &'a strThe object this entry is loaded from. This can be a filename on disk for the main binary and shared libraries, or virtual abstractions like “[vdso]”.
build_id: &'a strA string that uniquely identifies a particular program version with high probability. E.g., for binaries generated by GNU tools, it could be the contents of the .note.gnu.build-id field.