pub struct Sample<'a> {
pub locations: Vec<Location<'a>>,
pub values: &'a [i64],
pub labels: Vec<Label<'a>>,
}Fields
locations: Vec<Location<'a>>The leaf is at locations[0].
values: &'a [i64]The type and unit of each value is defined by the corresponding entry in Profile.sample_type. All samples must have the same number of values, the same as the length of Profile.sample_type. When aggregating multiple samples into a single sample, the result has a list of values that is the element-wise sum of the lists of the originals.
labels: Vec<Label<'a>>label includes additional context for this sample. It can include things like a thread id, allocation size, etc