Module string_table

Module string_table 

Modules

wordpress_test_data

Structs

StringTable
Holds unique strings and provides StringIds that correspond to the order that the strings were inserted.
StringTableIter
A LendingIterator for a StringTable. Make one by calling StringTable::into_lending_iter.

Enums

Error

Traits

ArenaAllocator
A trait that indicates an allocator is arena allocator, meaning it doesn’t deallocate individual items, but deallocates their memory as a group when the arena is dropped.