socket_path_to_uri

Function socket_path_to_uri 

pub fn socket_path_to_uri(path: &Path) -> Result<Uri, Error>
Creates a new Uri, with the unix scheme, and the path to the socket encoded as a hex string, to prevent special characters in the url authority