Module internal

Module internal 

Modules

interning_api

Structs

EncodedProfile
Endpoints
Function
Represents a [pprof::Function] with some space-saving changes:
FunctionId
Label
LabelId
LabelSet
A canonical representation for sets of labels. You should only use the impl functions to modify this.
LabelSetId
Location
Represents a [pprof::Location] with some space-saving changes:
LocationId
Mapping
Represents a [pprof::Mapping] with some space-saving changes:
MappingId
Observations
ObservationsIntoIter
Profile
ProfiledEndpointsStats
Sample
SampleId
StackTrace
StackTraceId
UpscalingRule
UpscalingRules
ValueType
ValueType describes the semantics and measurement units of a value.

Enums

LabelValue

Type Aliases

Timestamp