pub struct Location {
pub mapping_id: Option<MappingId>,
pub function_id: FunctionId,
pub address: u64,
pub line: i64,
}Expand description
Represents a [pprof::Location] with some space-saving changes:
- The id is not stored on the struct. It’s stored in the container that holds the struct.
- ids for linked objects use 32-bit numbers instead of 64 bit ones.
- in libdatadog, we always use 1 Line per Location, so this is directly inlined into the struct.
Fields
mapping_id: Option<MappingId>function_id: FunctionIdaddress: u64line: i64Trait Implementations
Sourceimpl Item for Location
impl Item for Location
Sourcetype Id = LocationId
type Id = LocationId
The Id associated with this Item, e.g. Function -> FunctionId.
Sourceimpl Ord for Location
impl Ord for Location
Sourceimpl PartialOrd for Location
impl PartialOrd for Location
impl Copy for Location
impl Eq for Location
impl StructuralPartialEq for Location