Mapping

Struct Mapping 

pub struct Mapping {
    pub memory_start: u64,
    pub memory_limit: u64,
    pub file_offset: u64,
    pub filename: StringId,
    pub build_id: StringId,
}
Represents a [pprof::Mapping] with some space-saving changes:

  • The id is not stored on the struct. It’s stored in the container that holds the struct.
  • ids for linked objects use 32-bit numbers instead of 64 bit ones.

Fields

memory_start: u64

Address at which the binary (or DLL) is loaded into memory.

memory_limit: u64

The limit of the address range occupied by this mapping.

file_offset: u64

Offset in the binary that corresponds to the first mapped address.

filename: StringId

The object this entry is loaded from. This can be a filename on disk for the main binary and shared libraries, or virtual abstractions like “[vdso]”.

build_id: StringId

A string that uniquely identifies a particular program version with high probability. E.g., for binaries generated by GNU tools, it could be the contents of the .note.gnu.build-id field.