Module iter

Module iter 

Traits

IntoLendingIterator
Turn a collection of some sort into a LendingIterator.
LendingIterator
The LendingIterator is a version of an Iterator that can yield items with references into the lender. It is a well-known name and there are multiple crates which offer it, with differences. The needs here are small, and so rather than bring in a pre-1.0 crate, just make our own.