pub trait IntoLendingIterator {
type Iter: LendingIterator;
// Required method
fn into_lending_iter(self) -> Self::Iter;
}Expand description
Turn a collection of some sort into a LendingIterator.
pub trait IntoLendingIterator {
type Iter: LendingIterator;
// Required method
fn into_lending_iter(self) -> Self::Iter;
}Turn a collection of some sort into a LendingIterator.