Module profiles

Module profiles 

Modules

collections

Structs

Compressor
Used to compress profile data.
NoopObservationCodec
NoopProfileCodec
SizeRestrictedBuffer
This type wraps a Vec to provide a Write interface that has a max capacity that won’t be exceeded. Additionally, it gracefully handles out-of-memory conditions instead of panicking (unfortunately not compatible with the no-panic crate, though).
ZstdObservationCodec
ZstdProfileCodec

Traits

ObservationCodec
ProfileCodec

Type Aliases

DefaultObservationCodec
DefaultProfileCodec