Module collections

Module collections 

Structs

ConstString
ConstString is used to create the storage needed for static strings that back ThinStrs.
InlineSlice
InlineString
Set
SetId
SliceSet
Holds unique slices and provides handles to fetch them later.
StringRef
Represents a handle to a string that can be retrieved by the string set. The exact representation is not a public detail; it is only available so that it is known for FFI size and alignment.
ThinSlice
A struct which acts like a thin slice reference. It does this by storing
ThinStr
A struct which acts like a thin &str. It does this by storing the size of the string just before the bytes of the string.
UnsyncStringSet
Holds unique strings and provides StringRefs to fetch them later. This is a newtype around SliceSet to enforce UTF-8 invariants.

Enums

SetError

Constants

SET_MIN_CAPACITY
WELL_KNOWN_STRING_REFS

Type Aliases

SetHasher