pub struct SetId<T>(/* private fields */);Implementations
Sourceimpl<T> SetId<T>
impl<T> SetId<T>
Sourcepub fn cast<U>(self) -> SetId<U>
pub fn cast<U>(self) -> SetId<U>
Cast to another type. Although this is safe, using the result is not necessarily safe.
pub fn into_raw(self) -> NonNull<c_void>
Sourcepub unsafe fn from_raw(raw: NonNull<c_void>) -> Self
pub unsafe fn from_raw(raw: NonNull<c_void>) -> Self
Re-creates a SetId from calling SetId::into_raw.
Safety
The set it belongs to must still be alive, and the repr should be
unchanged since it was created by SetId::into_raw.