StringRef

Struct StringRef 

#[repr(transparent)]
pub struct StringRef(pub ThinStr<'static>);
Represents a handle to a string that can be retrieved by the string set. The exact representation is not a public detail; it is only available so that it is known for FFI size and alignment.

Some StringRefs refer to well-known strings, which always exist in every string table.

The caller needs to ensure the string set it was created from always exists when a StringId is dereferenced.

Tuple Fields

0: ThinStr<'static>

Implementations

Source

impl StringRef

pub fn into_raw(self) -> NonNull<c_void>

pub unsafe fn from_raw(this: NonNull<c_void>) -> Self

Re-creates a StringRef created by StringRef::into_raw.

Safety

this needs to be created from ``StringRef::into_raw` and the set it belongs to should still be alive.

Source

impl StringRef