SizeRestrictedBuffer

Struct SizeRestrictedBuffer 

pub struct SizeRestrictedBuffer { /* private fields */ }
This type wraps a Vec to provide a Write interface that has a max capacity that won’t be exceeded. Additionally, it gracefully handles out-of-memory conditions instead of panicking (unfortunately not compatible with the no-panic crate, though).

Implementations

Source

impl SizeRestrictedBuffer

pub const fn zero_capacity() -> Self

Returns a buffer which can never hold any data.

pub fn try_new(size_hint: usize, max_capacity: usize) -> Result<Self>

Tries to create an initial buffer with the provided size hint as well as the provided max capacity. Neither number is required to be a power of 2.

Errors
  • Fails if the size_hint is larger than the max_capacity.
  • Fails if memory cannot be reserved.
pub fn as_slice(&self) -> &[u8]