pub trait ArenaAllocator: Allocator {
// Provided method
fn allocate(&self, str: &str) -> Result<&str, AllocError> { ... }
}Expand description
A trait that indicates an allocator is arena allocator, meaning it doesn’t deallocate individual items, but deallocates their memory as a group when the arena is dropped.