Module config
Source - agent
- Creates an Endpoint for talking to the Datadog agent.
- agent_uds
- Creates an Endpoint for talking to the Datadog agent though a unix socket.
- agentless
- Creates an Endpoint for talking to Datadog intake without using the agent.
This is an experimental feature.
- file