ProfileExporter

Struct ProfileExporter 

pub struct ProfileExporter { /* private fields */ }

Implementations

Source

impl ProfileExporter

pub fn new<F, N, V>( profiling_library_name: N, profiling_library_version: V, family: F, tags: Option<Vec<Tag>>, endpoint: Endpoint, ) -> Result<ProfileExporter>
where F: Into<Cow<'static, str>>, N: Into<Cow<'static, str>>, V: Into<Cow<'static, str>>,

Creates a new exporter to be used to report profiling data.

Arguments
  • profiling_library_name - Profiling library name, usually dd-trace-something, e.g. “dd-trace-rb”. See https://datadoghq.atlassian.net/wiki/spaces/PROF/pages/1538884229/Client#Header-values (Datadog internal link) for a list of common values.
  • profiling_library_version - Version used when publishing the profiling library to a package manager
  • family - Profile family, e.g. “ruby”
  • tags - Tags to include with every profile reported by this exporter. It’s also possible to include profile-specific tags, see additional_tags on build.
  • endpoint - Configuration for reporting data
pub fn build( &self, profile: EncodedProfile, files_to_compress_and_export: &[File<'_>], files_to_export_unmodified: &[File<'_>], additional_tags: Option<&Vec<Tag>>, internal_metadata: Option<Value>, info: Option<Value>, ) -> Result<Request>

Build a Request object representing the profile information provided.

Consumes the EncodedProfile, which is unavailable for use after.

For details on the internal_metadata parameter, please reference the Datadog-internal “RFC: Attaching internal metadata to pprof profiles”. If you use this parameter, please update the RFC with your use-case, so we can keep track of how this is getting used.

For details on the info parameter, please reference the Datadog-internal “RFC: Pprof System Info Support”.

pub fn send( &self, request: Request, cancel: Option<&CancellationToken>, ) -> Result<HttpResponse>

pub fn set_timeout(&mut self, timeout_ms: u64)