Structs
- Const
String ConstStringis used to create the storage needed for static strings that backThinStrs.- Inline
Slice - Inline
String - Set
- SetId
- Slice
Set - Holds unique slices and provides handles to fetch them later.
- String
Ref - Represents a handle to a string that can be retrieved by the string set. The exact representation is not a public detail; it is only available so that it is known for FFI size and alignment.
- Thin
Slice - A struct which acts like a thin slice reference. It does this by storing
- ThinStr
- A struct which acts like a thin &str. It does this by storing the size of the string just before the bytes of the string.
- Unsync
String Set - Holds unique strings and provides
StringRefs to fetch them later. This is a newtype around SliceSetto enforce UTF-8 invariants.