#[repr(transparent)]pub struct StringRef(pub ThinStr<'static>);Expand description
Represents a handle to a string that can be retrieved by the string set. The exact representation is not a public detail; it is only available so that it is known for FFI size and alignment.
Some StringRefs refer to well-known strings, which always exist in
every string table.
The caller needs to ensure the string set it was created from always exists when a StringId is dereferenced.
Tuple Fields
0: ThinStr<'static>Implementations