pub struct SizeRestrictedBuffer { /* private fields */ }Expand description
Implementations
Sourceimpl SizeRestrictedBuffer
impl SizeRestrictedBuffer
Sourcepub const fn zero_capacity() -> Self
pub const fn zero_capacity() -> Self
Returns a buffer which can never hold any data.
Sourcepub fn try_new(size_hint: usize, max_capacity: usize) -> Result<Self>
pub fn try_new(size_hint: usize, max_capacity: usize) -> Result<Self>
Tries to create an initial buffer with the provided size hint as well as the provided max capacity. Neither number is required to be a power of 2.
Errors
- Fails if the
size_hintis larger than themax_capacity. - Fails if memory cannot be reserved.
pub fn as_slice(&self) -> &[u8] ⓘ